# systemd options
%global _has_systemd %(eval rpm -q --quiet systemd && systemctl --version | head -n 1 | cut -d " " -f 2 || echo 0)
%if %{_has_systemd}
  %global _servicefile_postfix %{_has_systemd}.service
  %global _pidbasedir /run
%else
  %global _servicefile_postfix init
  %global _pidbasedir %{_var}/run
%endif

Summary: HPE Smart Array devices monitoring tool
Name: ccissmon
Version: 2.2.10
Release: 4%{?dist}
Group: System Environment/Daemons
License: GPLv2+
Packager: Simon Matter <simon.matter@invoca.ch>
Vendor: Invoca Systems
Distribution: Invoca Linux Server
Source0: %{name}.%{_servicefile_postfix}
Source1: %{name}.sysconfig
Source2: %{name}.sh.in
Source3: %{name}.cron
%if %{_has_systemd}
Source4: %{name}-tmpfiles.conf
%endif
Source5: README.%{name}
Source6: CREDITS.%{name}
Source7: http://www.gnu.org/licenses/gpl.txt
Requires: sendEmail >= 1.50, beep, sed, grep, util-linux, cciss_vol_status
%if %{_has_systemd}
BuildRequires: systemd
%systemd_requires
%else
Requires(post): /sbin/chkconfig
Requires(preun): /sbin/chkconfig, /sbin/service
Requires(postun): /sbin/service
%endif
BuildRequires: sed
BuildArch: noarch
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
Ccissmon is a shell script which runs as a daemon and monitors HPE Smart
Array devices. It starts to beep when a disk fails or while an array is
resyncing. Every event also triggers the email alert mechanism, which
sends mail to one or more persons with the details of what's going on.

%prep
%{__install} -d %{_builddir}/%{name}-%{version}
%{__install} -m 0644 -p %{SOURCE5} %{_builddir}/%{name}-%{version}/README
%{__install} -m 0644 -p %{SOURCE6} %{_builddir}/%{name}-%{version}/CREDITS
%{__install} -m 0644 -p %{SOURCE7} %{_builddir}/%{name}-%{version}/LICENSE

%install
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%{__install} -d %{buildroot}%{_sysconfdir}/sysconfig
%{__install} -d %{buildroot}%{_sysconfdir}/cron.daily
%{__install} -d %{buildroot}%{_bindir}
%{__install} -d %{buildroot}%{_pidbasedir}/%{name}

%if %{_has_systemd}
%{__install} -d %{buildroot}%{_prefix}/lib/tmpfiles.d
%{__install} -d %{buildroot}%{_unitdir}
%{__install} -m 0644 -p %{SOURCE4} %{buildroot}%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{__install} -m 0644 -p %{SOURCE0} %{buildroot}%{_unitdir}/%{name}.service
%else
%{__install} -d %{buildroot}%{_initrddir}
%{__install} -m 0755 -p %{SOURCE0} %{buildroot}%{_initrddir}/%{name}
%endif

%{__install} -m 0644 -p %{SOURCE1} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__sed} -e "s@/var/run@%{_pidbasedir}@g" %{SOURCE2} > %{buildroot}%{_bindir}/%{name}
%{__chmod} 0755 %{buildroot}%{_bindir}/%{name}
%{__install} -m 0755 -p %{SOURCE3} %{buildroot}%{_sysconfdir}/cron.daily/0%{name}

%clean
[ "%{buildroot}" != "/" ] && %{__rm} -rf %{buildroot}

%post
%if %{_has_systemd}
%systemd_post %{name}.service
%else
/sbin/chkconfig --add %{name}
%endif

%preun
%if %{_has_systemd}
%systemd_preun %{name}.service
%else
if [ $1 -eq 0 ]; then
  /sbin/service %{name} stop > /dev/null 2>&1 || :
  /sbin/chkconfig --del %{name}
fi
%endif

%postun
%if %{_has_systemd}
%{_bindir}/systemctl daemon-reload > /dev/null 2>&1 || :
if [ $1 -ge 1 ]; then
  %{_bindir}/%{name} try-restart > /dev/null 2>&1 || :
fi
%else
if [ $1 -ge 1 ]; then
  /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi
%endif

%files
%defattr(-,root,root,-)
%doc %{name}-%{version}/README %{name}-%{version}/CREDITS %{name}-%{version}/LICENSE
%{_bindir}/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%if %{_has_systemd}
%{_prefix}/lib/tmpfiles.d/%{name}.conf
%{_unitdir}/%{name}.service
%else
%attr(0755,root,root) %config %{_initrddir}/%{name}
%endif
%attr(0755,root,root) %dir %{_pidbasedir}/%{name}
%attr(0755,root,root) %config %{_sysconfdir}/cron.daily/0%{name}

%changelog
* Mon Mar 06 2023 Simon Matter <simon.matter@invoca.ch> 2.2.10-4
- add also Wants=network-online.target to systemd unit files

* Fri Mar 03 2023 Simon Matter <simon.matter@invoca.ch> 2.2.10-3
- add network-online requirement to systemd unit files

* Fri Mar 03 2023 Simon Matter <simon.matter@invoca.ch> 2.2.10-1
- upgrade to 2.2.10

* Thu Mar 02 2023 Simon Matter <simon.matter@invoca.ch> 2.2.9-1
- upgrade to 2.2.9

* Thu Mar 02 2023 Simon Matter <simon.matter@invoca.ch> 2.2.8-1
- upgrade to 2.2.8

* Thu Mar 02 2023 Simon Matter <simon.matter@invoca.ch> 2.2.7-1
- upgrade to 2.2.7

* Mon Jan 23 2023 Simon Matter <simon.matter@invoca.ch> 2.2.6-1
- upgrade to 2.2.6

* Thu Aug 19 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-3
- improve init script

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-2
- fix inconsistency between init scripts and systemd

* Wed Aug 18 2021 Simon Matter <simon.matter@invoca.ch> 2.2.5-1
- upgrade to 2.2.5

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.2.4-1
- upgrade to 2.2.4

* Tue Aug 17 2021 Simon Matter <simon.matter@invoca.ch> 2.2.3-1
- upgrade to 2.2.3

* Sat Aug 14 2021 Simon Matter <simon.matter@invoca.ch> 2.2.2-1
- upgrade to 2.2.2

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.2.1-1
- upgrade to 2.2.1

* Fri Aug 13 2021 Simon Matter <simon.matter@invoca.ch> 2.2.0-1
- upgrade to 2.2.0

* Fri Dec 04 2020 Simon Matter <simon.matter@invoca.ch> 2.1.7-1
- upgrade to 2.1.7

* Mon Apr 20 2020 Simon Matter <simon.matter@invoca.ch> 2.1.6-1
- upgrade to 2.1.6
- add support for EL8

* Thu Apr 25 2019 Simon Matter <simon.matter@invoca.ch> 2.1.5-1
- upgrade to 2.1.5

* Mon Feb 04 2019 Simon Matter <simon.matter@invoca.ch> 2.1.4-1
- upgrade to 2.1.4

* Thu Sep 13 2018 Simon Matter <simon.matter@invoca.ch> 2.1.3-1
- upgrade to 2.1.3

* Tue Sep 11 2018 Simon Matter <simon.matter@invoca.ch> 2.1.2-1
- upgrade to 2.1.2

* Tue Sep 11 2018 Simon Matter <simon.matter@invoca.ch> 2.1.0-1
- upgrade to 2.1.0

* Thu Sep 06 2018 Simon Matter <simon.matter@invoca.ch> 2.0.9-1
- upgrade to 2.0.9

* Fri Aug 31 2018 Simon Matter <simon.matter@invoca.ch> 2.0.7-1
- upgrade to 2.0.7

* Wed Jun 27 2018 Simon Matter <simon.matter@invoca.ch> 2.0.6-1
- upgrade to 2.0.6

* Mon Jun 25 2018 Simon Matter <simon.matter@invoca.ch> 2.0.5-1
- upgrade to 2.0.5

* Fri May 29 2015 Simon Matter <simon.matter@invoca.ch> 2.0.4-1
- upgrade to 2.0.4

* Thu May 28 2015 Simon Matter <simon.matter@invoca.ch> 2.0.3-1
- upgrade to 2.0.3

* Mon May 18 2015 Simon Matter <simon.matter@invoca.ch> 2.0.2-1
- upgrade to 2.0.2

* Wed May 13 2015 Simon Matter <simon.matter@invoca.ch> 2.0.1-2
- small spec fixes for systemd

* Wed Apr 29 2015 Simon Matter <simon.matter@invoca.ch> 2.0.1-1
- upgrade to 2.0.1

* Tue Apr 28 2015 Simon Matter <simon.matter@invoca.ch> 2.0.0-1
- upgrade to 2.0.0
- add support for systemd

* Tue Nov 19 2013 Simon Matter <simon.matter@invoca.ch> 0.8.0-1
- upgrade to 0.8.0, report all warnings even if not critical

* Mon Feb 25 2013 Simon Matter <simon.matter@invoca.ch> 0.7.2-1
- bump version

* Mon Feb 25 2013 Simon Matter <simon.matter@invoca.ch> 0.7.1-1
- show more informations in status

* Thu Feb 14 2013 Simon Matter <simon.matter@invoca.ch> 0.7.0-1
- improve support for hpsa based systems

* Thu Nov 15 2012 Simon Matter <simon.matter@invoca.ch> 0.6.7-2
- increase priority of daily cron job

* Fri Nov 09 2012 Simon Matter <simon.matter@invoca.ch> 0.6.7-1
- upgrade to 0.6.7, fix signal handling

* Thu Nov 08 2012 Simon Matter <simon.matter@invoca.ch> 0.6.6-1
- upgrade to 0.6.6, fix signal handling

* Fri Apr 15 2011 Simon Matter <simon.matter@invoca.ch> 0.6.5-2
- mass rebuild

* Fri Dec 03 2010 Simon Matter <simon.matter@invoca.ch> 0.6.5-1
- upgrade to 0.6.5, show version of cciss_vol_status in status mails

* Tue Sep 22 2009 Simon Matter <simon.matter@invoca.ch> 0.6.4-1
- upgrade to 0.6.4, check more hardware, not only disk arrays

* Sat Sep 27 2008 Simon Matter <simon.matter@invoca.ch> 0.6.3-1
- upgrade to 0.6.3, fix issue with restarting, add pid handling

* Fri Sep 26 2008 Simon Matter <simon.matter@invoca.ch> 0.6.1-1
- upgrade to 0.6.1, fix error messages from beep on XEN DomU's

* Fri Sep 26 2008 Simon Matter <simon.matter@invoca.ch> 0.6.0-1
- upgrade to 0.6.0, adds signal handler and proper daemonizing

* Fri Oct 12 2007 Simon Matter <simon.matter@invoca.ch> 0.5.0-1
- bring in sync with raidmon

* Thu Oct 11 2007 Simon Matter <simon.matter@invoca.ch> 0.1.0-1
- initial build
